==> tencentcloud-sdk-java-3.1.210-sources.jar: com/tencentcloudapi/cr/v20180321/models/QueryCallListResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cr.v20180321.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class QueryCallListResponse extends AbstractModel{

    /**
    * 任务作业状态
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("CallList")
    @Expose
    private CallInfo [] CallList;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 任务作业状态
注意：此字段可能返回 null，表示取不到有效值。 
     * @return CallList 任务作业状态
注意：此字段可能返回 null，表示取不到有效值。
     */
    public CallInfo [] getCallList() {
        return this.CallList;
    }

    /**
     * Set 任务作业状态
注意：此字段可能返回 null，表示取不到有效值。
     * @param CallList 任务作业状态
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setCallList(CallInfo [] CallList) {
        this.CallList = CallList;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "CallList.", this.CallList);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}

==> tencentcloud-sdk-java-3.1.696-sources.jar: com/tencentcloudapi/cr/v20180321/models/QueryCallListResponse.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.cr.v20180321.models;

import com.tencentcloudapi.common.AbstractModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class QueryCallListResponse extends AbstractModel{

    /**
    * 任务作业状态
注意：此字段可能返回 null，表示取不到有效值。
    */
    @SerializedName("CallList")
    @Expose
    private CallInfo [] CallList;

    /**
    * 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
    */
    @SerializedName("RequestId")
    @Expose
    private String RequestId;

    /**
     * Get 任务作业状态
注意：此字段可能返回 null，表示取不到有效值。 
     * @return CallList 任务作业状态
注意：此字段可能返回 null，表示取不到有效值。
     */
    public CallInfo [] getCallList() {
        return this.CallList;
    }

    /**
     * Set 任务作业状态
注意：此字段可能返回 null，表示取不到有效值。
     * @param CallList 任务作业状态
注意：此字段可能返回 null，表示取不到有效值。
     */
    public void setCallList(CallInfo [] CallList) {
        this.CallList = CallList;
    }

    /**
     * Get 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。 
     * @return RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public String getRequestId() {
        return this.RequestId;
    }

    /**
     * Set 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     * @param RequestId 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
     */
    public void setRequestId(String RequestId) {
        this.RequestId = RequestId;
    }

    public QueryCallListResponse() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public QueryCallListResponse(QueryCallListResponse source) {
        if (source.CallList != null) {
            this.CallList = new CallInfo[source.CallList.length];
            for (int i = 0; i < source.CallList.length; i++) {
                this.CallList[i] = new CallInfo(source.CallList[i]);
            }
        }
        if (source.RequestId != null) {
            this.RequestId = new String(source.RequestId);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamArrayObj(map, prefix + "CallList.", this.CallList);
        this.setParamSimple(map, prefix + "RequestId", this.RequestId);

    }
}
